local AddName, AddonTable = ...
local L = AddonTable.L

------------------------------
--		Options Equates		--
------------------------------
local Both, Enhanced, Base = 3, 1, 2

----------------------------------
--		Text Return Formats		--
----------------------------------
local Double_Rating_Format = { "%.0f", "%.0f", "%.0f/%.0f", }
local Base_Casting_Format = { "%.2f", "%.2f", "%.2f/%.2f", }

--------------------------
--		Physical		--
--------------------------
-- Intellect
function AddonTable.FunctionList.Intellect(HUD, data, options, ...)

	local EB, enhancedStat, baseStat = options.Enhanced_Base
	local _, stat, posBuff, negBuff = UnitStat("Player", 4)
	local debuffColor = ""
	local returnText
	
	if negBuff < 0 then debuffColor = "|cffC41E3A" end

	if AddonTable.Band(EB, Enhanced) then returnText = debuffColor .. stat end
	if AddonTable.Band(EB, Base) then returnText = stat end
	if AddonTable.Band(EB, Both) then returnText = debuffColor .. stat .. "|r/" .. stat end
	
	if returnText == nil then returnText = 0 end		

	HUD:UpdateText(data, returnText)
end

-- Spell Power
function AddonTable.FunctionList.SpellPower(HUD, data, options, ...)

	local EB, enhancedStat, baseStat = options.Enhanced_Base
	local statFormat = Double_Rating_Format[EB]
	local spellPower = 0
	local holySchool = GetSpellBonusDamage(2);
	local fireSchool = GetSpellBonusDamage(3);	
	local natureSchool = GetSpellBonusDamage(4);
	local frostSchool = GetSpellBonusDamage(5);  	
	local shadowSchool = GetSpellBonusDamage(6);                        
	local arcaneSchool = GetSpellBonusDamage(7);
	
	spellPower = max(holySchool, fireSchool, natureSchool, frostSchool, shadowSchool, arcaneSchool)
	local basePower = spellPower
	spellPower = spellPower + (spellPower * AddonTable.shatteringStar) + (spellPower * AddonTable.radiantSpark) + (spellPower * AddonTable.chaosBrand) + (spellPower * AddonTable.felSunder) + (spellPower * AddonTable.serenity) +
				(spellPower * AddonTable.luckOfDraw)

	if AddonTable.Band(EB, Enhanced) then enhancedStat = spellPower end
	if AddonTable.Band(EB, Base) then baseStat = basePower end
	
	HUD:UpdateText(data, format(statFormat, enhancedStat and enhancedStat or baseStat, baseStat))
end

-- Healing Power
function AddonTable.FunctionList.Healing(HUD, data, options, ...)

	local EB, enhancedStat, baseStat = options.Enhanced_Base
	local statFormat = Double_Rating_Format[EB]
	local healPower = GetSpellBonusHealing()
	
	healPower = healPower + (healPower * AddonTable.serenity) + (healPower * AddonTable.luckOfDraw)

	if AddonTable.Band(EB, Enhanced) then enhancedStat = healPower end
	if AddonTable.Band(EB, Base) then baseStat = healPower end
	
	HUD:UpdateText(data, format(statFormat, enhancedStat and enhancedStat or baseStat, baseStat))
end

-- Mana Regen
function AddonTable.FunctionList.ManaRegen(HUD, data, options, ...)

	local EB, enhancedStat, baseStat = options.Enhanced_Base
	local regenBase, regenCasting = GetManaRegen()
	local returnText, decimals
	regenBase = regenBase * 5
	regenCasting = (regenCasting * 5)
	
	if options.Decimals_ManaRegen == 0 then decimals = "%.0f"
	elseif options.Decimals_ManaRegen == 1 then decimals = "%.1f"
	elseif options.Decimals_ManaRegen == 2 then decimals = "%.2f"
	else decimals = "%.3f" end		

	if AddonTable.Band(EB, Enhanced) then returnText = (decimals):format(regenBase) end
	if AddonTable.Band(EB, Base) then returnText = (decimals):format(regenCasting) end
	if AddonTable.Band(EB, Both) then returnText = (decimals):format(regenBase) .. " (" .. (decimals):format(regenCasting) .. ")" end
	
	HUD:UpdateText(data, returnText)
end
